Converter of MCEG  files from old EIC generators to HEPMC.

Provides command line interface (CLI) and python API to convert old (and not old) event
generators mainly used for EIC to HepMC.

**CLI supported types** (out of the box):

- LUND (vanilla pythia6)
- LUND GEMC (various generators especially from Clas12)
- Pythia6 RadCor (aka Pythia-EIC, Pythia6-BNL, Pythia6-HERMES)
- Beagle
- Eic-smear (aka Eic-tree)

**Python API supported types**

- Any type of text event+particles formats
- Eic-smear (aka Eic-tree)
